'use client'

import React, { useState } from 'react'
import { motion, AnimatePresence } from 'framer-motion'

const WhatsAppIcon = () => (
  <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="currentColor" className="w-6 h-6">
    <path d="M12 2C6.48 2 2 6.48 2 12c0 2.17.7 4.19 1.94 5.86L2.87 21l3.23-1.01c1.57.9 3.38 1.42 5.33 1.42 5.52 0 10-4.48 10-10S17.52 2 12 2zm.03 15.88c-1.45 0-2.84-.4-4.03-1.15l-2.81.87.89-2.65c-.84-1.27-1.3-2.79-1.3-4.41 0-4.41 3.59-8 8-8s8 3.59 8 8-3.59 8-8 8zm4.63-5.88c-.24-.12-1.41-.69-1.63-.77-.22-.08-.38-.12-.54.12-.16.24-.62.77-.76.93-.14.16-.27.18-.51.06-.24-.12-1.01-.37-1.92-1.17-.71-.63-1.19-1.41-1.33-1.65-.14-.24-.02-.37.1-.49.11-.11.24-.29.36-.43.12-.14.16-.24.24-.4.08-.16.04-.3-.02-.43-.06-.12-.54-1.3-.74-1.78-.19-.47-.39-.4-.54-.41-.14-.01-.3-.01-.46-.01-.16 0-.43.06-.65.3-.22.24-.86.84-.86 2.05 0 1.21.88 2.38 1 2.54.12.16 1.69 2.59 4.1 3.63.57.25 1.02.4 1.37.51.58.19 1.1.16 1.51.1.46-.07 1.41-.58 1.61-1.14.2-.56.2-1.04.14-1.14-.06-.1-.22-.16-.46-.28z"/>
  </svg>
)

const ChatIcon = () => (
  <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="currentColor" className="w-6 h-6">
    <path d="M20 2H4c-1.1 0-2 .9-2 2v18l4-4h14c1.1 0 2-.9 2-2V4c0-1.1-.9-2-2-2zm0 14H6l-2 2V4h16v12z"/>
    <path d="M7 9h10v2H7zm0-3h10v2H7zm0 6h7v2H7z"/>
  </svg>
)

export default function FloatingIconSection() {
  const [isExpanded, setIsExpanded] = useState(false)

  return (
    <div className="fis-container fixed bottom-4 right-4 z-50">
      <AnimatePresence>
        {isExpanded && (
          <motion.div
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            exit={{ opacity: 0, y: 20 }}
            className="fis-expanded-icons mb-2 flex flex-col space-y-2"
          >
            <a
              href="https://wa.me/1234567890"
              target="_blank"
              rel="noopener noreferrer"
              className="fis-whatsapp-btn bg-green-500 text-white p-3 rounded-full shadow-lg hover:bg-green-600 transition-colors duration-300"
              aria-label="Contact us on WhatsApp"
            >
              <WhatsAppIcon />
            </a>
            <button
              onClick={() => console.log('Open chat')}
              className="fis-chat-btn bg-blue-500 text-white p-3 rounded-full shadow-lg hover:bg-blue-600 transition-colors duration-300"
              aria-label="Open chat"
            >
              <ChatIcon />
            </button>
          </motion.div>
        )}
      </AnimatePresence>
      <motion.button
        className="fis-toggle-btn bg-gray-800 text-white p-4 rounded-full shadow-lg hover:bg-gray-700 transition-colors duration-300"
        onClick={() => setIsExpanded(!isExpanded)}
        whileTap={{ scale: 0.95 }}
        aria-label="Toggle contact options"
      >
        <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="currentColor" className="w-6 h-6">
          <path d="M20 2H4c-1.1 0-2 .9-2 2v18l4-4h14c1.1 0 2-.9 2-2V4c0-1.1-.9-2-2-2zm0 14H6l-2 2V4h16v12z"/>
          <path d="M7 9h2v2H7zm4 0h2v2h-2zm4 0h2v2h-2z"/>
        </svg>
      </motion.button>
    </div>
  )
}